@@ -35,6 +35,9 @@ my %dispatch = (
     stroke          => 'stroke',
     show_boxed      => 'show_boxed',
     show_xy         => 'show_xy',
+    open_image      => 'open_image_file',
+    close_image     => 'close_image',
+    place_image     => 'place_image',
 );
 
 sub new {
@@ -84,6 +87,18 @@ sub font_size {
     return pdflib_pl::PDF_get_value($p, 'fontsize', undef);
 }
 
+sub image_width {
+    my $self = shift; my $p = $self->{pdf};
+    my ($image) = @_;
+    return pdflib_pl::PDF_get_value($p, 'imagewidth', $image);
+}
+
+sub image_height {
+    my $self = shift; my $p = $self->{pdf};
+    my ($image) = @_;
+    return pdflib_pl::PDF_get_value($p, 'imageheight', $image);
+}
+
 while (my ($k, $v) = each %dispatch) {
     no strict 'refs';
     my $method = "pdflib_pl::PDF_$v";
